SystemOrganization addCategory: #ConfigurationOfSomethingIt!
(PackageInfo named: 'ConfigurationOfSomethingIt') postscript: '"below, add code to be run after the loading of this package"
ConfigurationOfSomethingIt load'!

Object subclass: #ConfigurationOfSomethingIt
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfSomethingIt'!

!ConfigurationOfSomethingIt commentStamp: '<historical>' prior: 0!
OSProcess provides access to operating system functions, including pipes and child process creation. It is implemented using pluggable primitives in a shared library for Unix or Linux, and a DLL for Windows. The Smalltalk code, including the classes which implement pluggable primitives for Unix or Win32 operating system functions, may be loaded into any Squeak image, but the primitives are only useful on Unix and Windows systems. Placeholder classes are provided for MacOS, OS/2 and RiscOS, but are not yet implemented.!

!ConfigurationOfSomethingIt class methodsFor: 'private' stamp: 'TO 10/19/2012 14:11'!
bootstrapPackage: aString from: aPath 
	| repository version |
	repository := MCHttpRepository
				location: aPath
				user: ''
				password: ''.
	repository
		versionReaderForFileNamed: aString , '.mcz'
		do: [:reader | 
			version := reader version.
			version load.
			version workingCopy repositoryGroup addRepository: repository]! !

!ConfigurationOfSomethingIt class methodsFor: 'private' stamp: 'TO 10/19/2012 14:11'!
ensureMetacello
	"Bootstrap Gofer (if necessary), bootstrap ConfigurationOfMetacello (using old Gofer API), then load the latest 
	version of Metacello itself."

	Smalltalk at: #MetacelloProject ifAbsent: [
		Smalltalk at: #Gofer ifAbsent: [
			"Current version of Gofer from which to bootstrap - as of 1.0-beta.15"
			self bootstrapPackage: 'Gofer-lr.83' from: 'http://seaside.gemstone.com/ss/metacello' ].
		Smalltalk at: #Gofer ifPresent: [:goferClass | | gofer |
			gofer := goferClass new
				url: 'http://seaside.gemstone.com/ss/metacello';
				yourself.
			[ gofer addPackage: 'ConfigurationOfMetacello' ] on: Warning do: [:ex | ex resume ].
			gofer load ].
		"load 'default' group of Metacello"
		(Smalltalk at: #ConfigurationOfMetacello) perform: #load ]! !

!ConfigurationOfSomethingIt class methodsFor: 'metacello tool support' stamp: 'TO 10/19/2012 14:11'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfSomethingIt class methodsFor: 'metacello tool support' stamp: 'TO 10/19/2012 14:11'!
lastMetacelloVersionLoad
	"Answer the last version loaded and the list of packages loaded for that version."

	LastVersionLoad == nil ifTrue: [ LastVersionLoad := nil -> 'default' ].
	^LastVersionLoad! !

!ConfigurationOfSomethingIt class methodsFor: 'loading' stamp: 'TO 10/19/2012 14:11'!
load
	"self load"

	| r |
	r := self project latestVersion load.
	(Smalltalk at: #ThisOSProcess) ifNotNilDo: [ :osp | osp startUp: true ] "initialize"! !

!ConfigurationOfSomethingIt class methodsFor: 'metacello tool support' stamp: 'TO 10/19/2012 14:11'!
metacelloVersion: versionString loads: anArrayOrString
	"Stash the last version loaded and the list of packages loaded for that version. The list
	 of packages will be used by the tools when doing 'Load Package Version'"

	LastVersionLoad := versionString -> anArrayOrString! !

!ConfigurationOfSomethingIt class methodsFor: 'accessing' stamp: 'TO 10/19/2012 14:11'!
project

	^self new project! !

!ConfigurationOfSomethingIt methodsFor: 'baselines' stamp: 'tomooda 10/20/2012 04:29'!
baseline001: spec 
	<version: '0.1-baseline'>
	spec
		for: #common
		do: [spec blessing: #baseline.
			spec description: 'Default configuration'.
			spec repository: 'http://squeaksource.blueplane.jp/SomethingIt'.
			spec
				package: 'OSProcess'
					with: [spec repository: 'http://www.squeaksource.com/OSProcess'];
				package: 'SomethingIt-Core'
					with: [spec requires: 'OSProcess'];
				package: 'SomethingIt-Haskell'
					with: [spec requires: 'SomethingIt-Core'];
				package: 'SomethingIt-VDM'
					with: [spec requires: 'SomethingIt-Core'];
				package: 'SomethingIt-Platform'		
		].
	spec for: #squeak do: [
		spec package: 'SomethingIt-Platform' with: 'SomethingIt-Platform.squeak']! !

!ConfigurationOfSomethingIt methodsFor: 'baselines' stamp: 'tomooda 10/20/2012 05:54'!
baseline002: spec 
	<version: '0.2-baseline'>
	spec
		for: #common
		do: [spec blessing: #baseline.
			spec description: 'Default configuration'.
			spec repository: 'http://squeaksource.blueplane.jp/SomethingIt'.
			spec
				package: 'OSProcess'
					with: [spec repository: 'http://www.squeaksource.com/OSProcess'];
				package: 'SomethingIt-Core'
					with: [spec requires: 'OSProcess'];
				package: 'SomethingIt-Haskell'
					with: [spec requires: 'SomethingIt-Core'];
				package: 'SomethingIt-VDM'
					with: [spec requires: 'SomethingIt-Core'];
				package: 'SomethingIt-Platform'		
		].
	spec for: #squeak do: [
		spec package: 'SomethingIt-Platform' with: 'SomethingIt-Platform.squeak'].
	spec for: #pharo do: [
		spec package: 'SomethingIt-Platform' with: 'SomethingIt-Platform.pharo']! !

!ConfigurationOfSomethingIt methodsFor: 'baselines' stamp: 'tomooda 10/20/2012 06:13'!
baseline100: spec 
	<version: '1.0-baseline'>
	spec
		for: #common
		do: [spec blessing: #baseline.
			spec description: 'Default configuration'.
			spec repository: 'http://squeaksource.blueplane.jp/SomethingIt'.
			spec
				package: 'OSProcess'
					with: [spec repository: 'http://www.squeaksource.com/OSProcess'];
				package: 'SomethingIt-Core'
					with: [spec requires: 'OSProcess'];
				package: 'SomethingIt-Haskell'
					with: [spec requires: 'SomethingIt-Core'];
				package: 'SomethingIt-VDM'
					with: [spec requires: 'SomethingIt-Core'];
				package: 'SomethingIt-Platform'
					with: [spec
						requires: 'SomethingIt-Core';
						requires: 'SomethingIt-Haskell']	
		].
	spec for: #squeak do: [
		spec package: 'SomethingIt-Platform' with: 'SomethingIt-Platform.squeak'].
	spec for: #pharo do: [
		spec package: 'SomethingIt-Platform' with: 'SomethingIt-Platform.pharo']! !

!ConfigurationOfSomethingIt methodsFor: 'baselines' stamp: 'tomooda 11/2/2012 10:43'!
baseline102: spec 
	<version: '1.2-baseline'>
	spec
		for: #common
		do: [spec blessing: #baseline.
			spec description: 'Default configuration'.
			spec repository: 'http://ss3.gemstone.com/ss/SomethingIt'.
			spec
				package: 'OSProcess'
					with: [spec repository: 'http://www.squeaksource.com/OSProcess'];
				package: 'SomethingIt-Core'
					with: [spec requires: 'OSProcess'];
				package: 'SomethingIt-Haskell'
					with: [spec requires: 'SomethingIt-Core'];
				package: 'SomethingIt-VDM'
					with: [spec requires: 'SomethingIt-Core'];
				package: 'SomethingIt-Platform'
					with: [spec
						requires: 'SomethingIt-Core';
						requires: 'SomethingIt-Haskell']	
		].
	spec for: #squeak do: [
		spec package: 'SomethingIt-Platform' with: 'SomethingIt-Platform.squeak'].
	spec for: #pharo do: [
		spec package: 'SomethingIt-Platform' with: 'SomethingIt-Platform.pharo']! !

!ConfigurationOfSomethingIt methodsFor: 'baselines' stamp: 'tomooda 8/5/2013 12:04'!
baseline105: spec 
	<version: '1.5-baseline'>
	spec
		for: #common
		do: [spec blessing: #baseline.
			spec description: 'Default configuration'.
			spec repository: 'http://ss3.gemstone.com/ss/SomethingIt'.
			spec
				package: 'OSProcess'
					with: [spec repository: 'http://www.squeaksource.com/OSProcess'];
				package: 'WebClient-Core'
					with: [spec repository: 'http://www.squeaksource.com/WebClient'];
				package: 'PetitParser'
					with: [spec repository: 'http://source.lukas-renggli.ch/petit'];
				package: 'SomethingIt-Core'
					with: [spec requires: 'OSProcess'];
				package: 'SomethingIt-Haskell'
					with: [spec requires: 'SomethingIt-Core'];
				package: 'SomethingIt-VDM'
					with: [spec requires: 'SomethingIt-Core'];
				package: 'SomethingIt-JavaScript'
					with: [spec
						requires: 'SomethingIt-Core';
						requires: 'WebClient-Core'];
				package: 'SomethingIt-Platform'
					with: [spec
						requires: 'SomethingIt-Core';
						requires: 'SomethingIt-Haskell']	
		].
	spec for: #squeak do: [
		spec package: 'SomethingIt-Platform' with: 'SomethingIt-Platform.squeak'].
	spec for: #pharo do: [
		spec package: 'SomethingIt-Platform' with: 'SomethingIt-Platform.pharo']! !

!ConfigurationOfSomethingIt methodsFor: 'baselines' stamp: 'tomooda 8/6/2013 11:13'!
baseline106: spec 
	<version: '1.6-baseline'>
	spec
		for: #common
		do: [spec blessing: #baseline.
			spec description: 'Default configuration'.
			spec repository: 'http://ss3.gemstone.com/ss/SomethingIt'.
			spec
				package: 'OSProcess'
				with: [spec repository: 'http://www.squeaksource.com/OSProcess'];
				
				package: 'WebClient-Core'
				with: [spec repository: 'http://www.squeaksource.com/WebClient'];
				
				package: 'PetitParser'
				with: [spec repository: 'http://source.lukas-renggli.ch/petit'];
				
				package: 'SomethingIt-Core'
				with: [spec requires: 'OSProcess'];
				
				package: 'SomethingIt-Haskell'
				with: [spec requires: 'SomethingIt-Core'];
				
				package: 'SomethingIt-VDM'
				with: [spec requires: 'SomethingIt-Core';
						 requires: 'WebClient-Core'];
				
				package: 'SomethingIt-JavaScript'
				with: [spec requires: 'SomethingIt-Core';
						 requires: 'WebClient-Core'];
				
				package: 'SomethingIt-Platform'
				with: [spec requires: 'SomethingIt-Core';
						 requires: 'SomethingIt-Haskell']].
	spec
		for: #squeak
		do: [spec package: 'SomethingIt-Platform' with: 'SomethingIt-Platform.squeak'].
	spec
		for: #pharo
		do: [spec package: 'SomethingIt-Platform' with: 'SomethingIt-Platform.pharo']! !

!ConfigurationOfSomethingIt methodsFor: 'private' stamp: 'TO 10/19/2012 14:20'!
loadType
	"#atomic for dense dependents config. #linear for loose
	dependents. "
	^ #linear! !

!ConfigurationOfSomethingIt methodsFor: 'accessing' stamp: 'TO 10/19/2012 14:11'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		self class ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: self loadType.
		project ]! !

!ConfigurationOfSomethingIt methodsFor: 'symbolic versions' stamp: 'tomooda 8/13/2013 15:33'!
stable: spec 
	<symbolicVersion: #stable>
	spec for: #common version: '1.8'! !

!ConfigurationOfSomethingIt methodsFor: 'versions' stamp: 'tomooda 10/20/2012 04:35'!
version001: spec 
	<version: '0.1' imports: #('0.1-baseline')>
	spec
		for: #common
		do: [spec blessing: #stable.
			spec description: 'The very initial version that works only on Squeak'.
			spec author: 'tomooda'.
			spec timestamp: '10/20/2012 16:40'.
			spec package: 'SomethingIt-Core' with: 'SomethingIt-Core-tomooda.1';
				 package: 'SomethingIt-Haskell' with: 'SomethingIt-Haskell-tomooda.1';
				 package: 'SomethingIt-VDM' with: 'SomethingIt-VDM-tomooda.1';
				 package: 'OSProcess' with: 'OSProcess-dtl.71'].
	spec
		for: #squeak
		do: [spec package: 'SomethingIt-Platform' with: 'SomethingIt-Platform.squeak-tomooda.2']! !

!ConfigurationOfSomethingIt methodsFor: 'versions' stamp: 'tomooda 10/20/2012 05:56'!
version002: spec 
	<version: '0.2' imports: #('0.2-baseline')>
	spec
		for: #common
		do: [spec blessing: #stable.
			spec description: 'The very initial version that works only on Squeak'.
			spec author: 'tomooda'.
			spec timestamp: '10/20/2012 05:56'.
			spec package: 'SomethingIt-Core' with: 'SomethingIt-Core-tomooda.1';
				 package: 'SomethingIt-Haskell' with: 'SomethingIt-Haskell-tomooda.1';
				 package: 'SomethingIt-VDM' with: 'SomethingIt-VDM-tomooda.1';
				 package: 'OSProcess' with: 'OSProcess-dtl.71'].
	spec
		for: #squeak
		do: [spec package: 'SomethingIt-Platform' with: 'SomethingIt-Platform.squeak-tomooda.2'].
	spec
		for: #pharo
		do: [spec package: 'SomethingIt-Platform' with: 'SomethingIt-Platform.pharo-tomooda.1']! !

!ConfigurationOfSomethingIt methodsFor: 'versions' stamp: 'tomooda 10/20/2012 06:07'!
version003: spec 
	<version: '0.3' imports: #('0.2-baseline')>
	spec
		for: #common
		do: [spec blessing: #stable.
			spec description: 'The very initial version that works only on Squeak'.
			spec author: 'tomooda'.
			spec timestamp: '10/20/2012 06:08'.
			spec package: 'SomethingIt-Core' with: 'SomethingIt-Core-tomooda.1';
				 package: 'SomethingIt-Haskell' with: 'SomethingIt-Haskell-tomooda.1';
				 package: 'SomethingIt-VDM' with: 'SomethingIt-VDM-tomooda.2';
				 package: 'OSProcess' with: 'OSProcess-dtl.71'].
	spec
		for: #squeak
		do: [spec package: 'SomethingIt-Platform' with: 'SomethingIt-Platform.squeak-tomooda.2'].
	spec
		for: #pharo
		do: [spec package: 'SomethingIt-Platform' with: 'SomethingIt-Platform.pharo-tomooda.1']! !

!ConfigurationOfSomethingIt methodsFor: 'versions' stamp: 'tomooda 10/20/2012 06:15'!
version100: spec 
	<version: '1.0' imports: #('1.0-baseline')>
	spec
		for: #common
		do: [spec blessing: #stable.
			spec description: 'The first release that works on squeak and pharo.'.
			spec author: 'tomooda'.
			spec timestamp: '10/20/2012 06:15'.
			spec package: 'SomethingIt-Core' with: 'SomethingIt-Core-tomooda.1';
				 package: 'SomethingIt-Haskell' with: 'SomethingIt-Haskell-tomooda.1';
				 package: 'SomethingIt-VDM' with: 'SomethingIt-VDM-tomooda.2';
				 package: 'OSProcess' with: 'OSProcess-dtl.71'].
	spec
		for: #squeak
		do: [spec package: 'SomethingIt-Platform' with: 'SomethingIt-Platform.squeak-tomooda.2'].
	spec
		for: #pharo
		do: [spec package: 'SomethingIt-Platform' with: 'SomethingIt-Platform.pharo-tomooda.1']! !

!ConfigurationOfSomethingIt methodsFor: 'versions' stamp: 'tomooda 10/20/2012 07:11'!
version101: spec 
	<version: '1.1' imports: #('1.0-baseline')>
	spec
		for: #common
		do: [spec blessing: #stable.
			spec description: 'The first release that works on squeak and pharo.'.
			spec author: 'tomooda'.
			spec timestamp: '10/20/2012 07:10'.
			spec package: 'SomethingIt-Core' with: 'SomethingIt-Core-tomooda.1';
				 package: 'SomethingIt-Haskell' with: 'SomethingIt-Haskell-tomooda.1';
				 package: 'SomethingIt-VDM' with: 'SomethingIt-VDM-tomooda.2';
				 package: 'OSProcess' with: 'OSProcess-dtl.71'].
	spec
		for: #squeak
		do: [spec package: 'SomethingIt-Platform' with: 'SomethingIt-Platform.squeak-tomooda.2'].
	spec
		for: #pharo
		do: [spec package: 'SomethingIt-Platform' with: 'SomethingIt-Platform.pharo-tomooda.2']! !

!ConfigurationOfSomethingIt methodsFor: 'versions' stamp: 'tomooda 11/2/2012 10:42'!
version102: spec 
	<version: '1.2' imports: #('1.2-baseline')>
	spec
		for: #common
		do: [spec blessing: #stable.
			spec description: 'Haskell/VDM-SL wrapper on squeak and pharo.'.
			spec author: 'tomooda'.
			spec timestamp: '11/02/2012 10:40'.
			spec package: 'SomethingIt-Core' with: 'SomethingIt-Core-tomooda.7';
				 package: 'SomethingIt-Haskell' with: 'SomethingIt-Haskell-tomooda.10';
				 package: 'SomethingIt-VDM' with: 'SomethingIt-VDM-tomooda.8';
				 package: 'OSProcess' with: 'OSProcess-dtl.71'].
	spec
		for: #squeak
		do: [spec package: 'SomethingIt-Platform' with: 'SomethingIt-Platform.squeak-tomooda.3'].
	spec
		for: #pharo
		do: [spec package: 'SomethingIt-Platform' with: 'SomethingIt-Platform.pharo-tomooda.3']! !

!ConfigurationOfSomethingIt methodsFor: 'versions' stamp: 'tomooda 2/26/2013 14:26'!
version103: spec 
	<version: '1.3' imports: #('1.2-baseline')>
	spec
		for: #common
		do: [spec blessing: #stable.
			spec description: 'Haskell/VDM-SL wrapper on squeak and pharo.'.
			spec author: 'tomooda'.
			spec timestamp: '02/26/2013 14:30'.
			spec package: 'SomethingIt-Core' with: 'SomethingIt-Core-tomooda.11';
				 package: 'SomethingIt-Haskell' with: 'SomethingIt-Haskell-tomooda.13';
				 package: 'SomethingIt-VDM' with: 'SomethingIt-VDM-tomooda.20';
				 package: 'OSProcess' with: 'OSProcess-dtl.71'].
	spec
		for: #squeak
		do: [spec package: 'SomethingIt-Platform' with: 'SomethingIt-Platform.squeak-tomooda.3'].
	spec
		for: #pharo
		do: [spec package: 'SomethingIt-Platform' with: 'SomethingIt-Platform.pharo-tomooda.3']! !

!ConfigurationOfSomethingIt methodsFor: 'versions' stamp: 'tomooda 3/6/2013 13:45'!
version104: spec 
	<version: '1.4' imports: #('1.2-baseline')>
	spec
		for: #common
		do: [spec blessing: #stable.
			spec description: 'Haskell/VDM-SL wrapper on squeak and pharo.'.
			spec author: 'tomooda'.
			spec timestamp: '02/26/2013 14:30'.
			spec package: 'SomethingIt-Core' with: 'SomethingIt-Core-tomooda.11';
				 package: 'SomethingIt-Haskell' with: 'SomethingIt-Haskell-tomooda.13';
				 package: 'SomethingIt-VDM' with: 'SomethingIt-VDM-tomooda.22';
				 package: 'OSProcess' with: 'OSProcess-dtl.71'].
	spec
		for: #squeak
		do: [spec package: 'SomethingIt-Platform' with: 'SomethingIt-Platform.squeak-tomooda.3'].
	spec
		for: #pharo
		do: [spec package: 'SomethingIt-Platform' with: 'SomethingIt-Platform.pharo-tomooda.3']! !

!ConfigurationOfSomethingIt methodsFor: 'versions' stamp: 'tomooda 8/5/2013 12:58'!
version105: spec 
	<version: '1.5' imports: #('1.5-baseline')>
	spec
		for: #common
		do: [spec blessing: #stable.
			spec description: 'Haskell/VDM-SL wrapper on squeak and pharo.'.
			spec author: 'tomooda'.
			spec timestamp: '08/05/2013 13:00'.
			spec package: 'SomethingIt-Core' with: 'SomethingIt-Core-tomooda.11';
				 package: 'SomethingIt-Haskell' with: 'SomethingIt-Haskell-tomooda.17';
				 package: 'SomethingIt-VDM' with: 'SomethingIt-VDM-tomooda.25';
				 package: 'SomethingIt-JavaScript' with: 'SomethingIt-JavaScript-tomooda.3';
				 package: 'PetitParser' with: 'PetitParser-lr.231';
				 package: 'WebClient-Core' with: 'WebClient-Core-ar.92';
				 package: 'OSProcess' with: 'OSProcess-dtl.71'].
	spec
		for: #squeak
		do: [spec package: 'SomethingIt-Platform' with: 'SomethingIt-Platform.squeak-tomooda.3'].
	spec
		for: #pharo
		do: [spec package: 'SomethingIt-Platform' with: 'SomethingIt-Platform.pharo-tomooda.3']! !

!ConfigurationOfSomethingIt methodsFor: 'versions' stamp: 'tomooda 8/6/2013 11:21'!
version106: spec 
	<version: '1.6' imports: #('1.6-baseline')>
	spec
		for: #common
		do: [spec blessing: #stable.
			spec description: 'Haskell/VDM-SL wrapper on squeak and pharo.'.
			spec author: 'tomooda'.
			spec timestamp: '08/06/2013 11:30'.
			spec package: 'SomethingIt-Core' with: 'SomethingIt-Core-tomooda.11';
				 package: 'SomethingIt-Haskell' with: 'SomethingIt-Haskell-tomooda.17';
				 package: 'SomethingIt-VDM' with: 'SomethingIt-VDM-tomooda.26';
				 package: 'SomethingIt-JavaScript' with: 'SomethingIt-JavaScript-tomooda.4';
				 package: 'PetitParser' with: 'PetitParser-lr.231';
				 package: 'WebClient-Core' with: 'WebClient-Core-ar.92';
				 package: 'OSProcess' with: 'OSProcess-dtl.71'].
	spec
		for: #squeak
		do: [spec package: 'SomethingIt-Platform' with: 'SomethingIt-Platform.squeak-tomooda.3'].
	spec
		for: #pharo
		do: [spec package: 'SomethingIt-Platform' with: 'SomethingIt-Platform.pharo-tomooda.3']! !

!ConfigurationOfSomethingIt methodsFor: 'versions' stamp: 'tomooda 8/13/2013 14:08'!
version107: spec 
	<version: '1.7' imports: #('1.6-baseline')>
	spec
		for: #common
		do: [spec blessing: #stable.
			spec description: 'Haskell/VDM-SL wrapper on squeak and pharo.'.
			spec author: 'tomooda'.
			spec timestamp: '08/06/2013 11:30'.
			spec package: 'SomethingIt-Core' with: 'SomethingIt-Core-tomooda.12';
				 package: 'SomethingIt-Haskell' with: 'SomethingIt-Haskell-tomooda.18';
				 package: 'SomethingIt-VDM' with: 'SomethingIt-VDM-tomooda.36';
				 package: 'SomethingIt-JavaScript' with: 'SomethingIt-JavaScript-tomooda.4';
				 package: 'PetitParser' with: 'PetitParser-lr.231';
				 package: 'WebClient-Core' with: 'WebClient-Core-ar.92';
				 package: 'OSProcess' with: 'OSProcess-dtl.71'].
	spec
		for: #squeak
		do: [spec package: 'SomethingIt-Platform' with: 'SomethingIt-Platform.squeak-tomooda.3'].
	spec
		for: #pharo
		do: [spec package: 'SomethingIt-Platform' with: 'SomethingIt-Platform.pharo-tomooda.3']! !

!ConfigurationOfSomethingIt methodsFor: 'versions' stamp: 'tomooda 8/13/2013 15:33'!
version108: spec 
	<version: '1.8' imports: #('1.6-baseline')>
	spec
		for: #common
		do: [spec blessing: #stable.
			spec description: 'Haskell/VDM-SL wrapper on squeak and pharo.'.
			spec author: 'tomooda'.
			spec timestamp: '08/06/2013 11:30'.
			spec package: 'SomethingIt-Core' with: 'SomethingIt-Core-tomooda.13';
				 package: 'SomethingIt-Haskell' with: 'SomethingIt-Haskell-tomooda.18';
				 package: 'SomethingIt-VDM' with: 'SomethingIt-VDM-tomooda.37';
				 package: 'SomethingIt-JavaScript' with: 'SomethingIt-JavaScript-tomooda.4';
				 package: 'PetitParser' with: 'PetitParser-lr.231';
				 package: 'WebClient-Core' with: 'WebClient-Core-ar.92';
				 package: 'OSProcess' with: 'OSProcess-dtl.71'].
	spec
		for: #squeak
		do: [spec package: 'SomethingIt-Platform' with: 'SomethingIt-Platform.squeak-tomooda.3'].
	spec
		for: #pharo
		do: [spec package: 'SomethingIt-Platform' with: 'SomethingIt-Platform.pharo-tomooda.3']! !

!ConfigurationOfSomethingIt methodsFor: 'versions' stamp: 'tomooda 8/20/2013 09:25'!
version109: spec 
	<version: '1.9' imports: #('1.6-baseline')>
	spec
		for: #common
		do: [spec blessing: #stable.
			spec description: 'Haskell/VDM-SL wrapper on squeak and pharo.'.
			spec author: 'tomooda'.
			spec timestamp: '08/06/2013 11:30'.
			spec package: 'SomethingIt-Core' with: 'SomethingIt-Core-tomooda.13';
				 package: 'SomethingIt-Haskell' with: 'SomethingIt-Haskell-tomooda.18';
				 package: 'SomethingIt-VDM' with: 'SomethingIt-VDM-tomooda.39';
				 package: 'SomethingIt-JavaScript' with: 'SomethingIt-JavaScript-tomooda.4';
				 package: 'PetitParser' with: 'PetitParser-lr.231';
				 package: 'WebClient-Core' with: 'WebClient-Core-ar.92';
				 package: 'OSProcess' with: 'OSProcess-dtl.71'].
	spec
		for: #squeak
		do: [spec package: 'SomethingIt-Platform' with: 'SomethingIt-Platform.squeak-tomooda.3'].
	spec
		for: #pharo
		do: [spec package: 'SomethingIt-Platform' with: 'SomethingIt-Platform.pharo-tomooda.3']! !

!ConfigurationOfSomethingIt methodsFor: 'versions' stamp: 'tomooda 8/20/2013 21:22'!
version110: spec 
	<version: '1.10' imports: #('1.6-baseline')>
	spec
		for: #common
		do: [spec blessing: #stable.
			spec description: 'Haskell/VDM-SL wrapper on squeak and pharo.'.
			spec author: 'tomooda'.
			spec timestamp: '08/06/2013 11:30'.
			spec package: 'SomethingIt-Core' with: 'SomethingIt-Core-tomooda.13';
				 package: 'SomethingIt-Haskell' with: 'SomethingIt-Haskell-tomooda.18';
				 package: 'SomethingIt-VDM' with: 'SomethingIt-VDM-tomooda.40';
				 package: 'SomethingIt-JavaScript' with: 'SomethingIt-JavaScript-tomooda.4';
				 package: 'PetitParser' with: 'PetitParser-lr.231';
				 package: 'WebClient-Core' with: 'WebClient-Core-ar.92';
				 package: 'OSProcess' with: 'OSProcess-dtl.71'].
	spec
		for: #squeak
		do: [spec package: 'SomethingIt-Platform' with: 'SomethingIt-Platform.squeak-tomooda.3'].
	spec
		for: #pharo
		do: [spec package: 'SomethingIt-Platform' with: 'SomethingIt-Platform.pharo-tomooda.3']! !
